Test Report

# index.html

Report generated on 08-Jun-2020 at 20:18:08 by pytest-html v2.1.1

## Environment

JAVA_HOME | /Library/Java/JavaVirtualMachines/jdk1.8.0_221.jdk/Contents/Home
Packages | {"pluggy": "0.13.1", "py": "1.8.1", "pytest": "5.4.3"}
Platform | Darwin-19.4.0-x86_64-i386-64bit
Plugins | {"allure-pytest": "2.8.16", "dependency": "0.5.1", "forked": "1.1.3", "html": "2.1.1", "metadata": "1.9.0", "ordering": "0.6", "xdist": "1.32.0"}
Python | 3.7.7

## Summary

1 tests ran in 1.57 seconds.

(Un)check the boxes to filter the results.

0 passed, 0 skipped, 1 failed, 0 errors, 0 expected failures, 0 unexpected passes

## Results

Result | Test | Duration | Links
--- | --- | --- | ---
No results found. Try to check the filters
Failed | test/test-api-auth.py::TestAPIAuth::test_basic_auth_ | 1.37 |
self = <test.test-api-auth.TestAPIAuth object at 0x10ad04590> def test_basic_auth_(self): auth_token = "12345abcde-token" base_url = "https://httpbin.org/get" resp = self.api_req.basic_auth_token_authentication_new(base_url, auth_token) > self.api_req.check_status(resp, '200') test/test-api-auth.py:95: _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ self = <base.APIHelpers.api_methods.APIMethods object at 0x109ea0310> resp = {'args': {}, 'headers': {'Accept': '*/*', 'Accept-Encoding': 'gzip, deflate', 'Host': 'httpbin.org', 'User-Agent': 'python-requests/2.23.0', ...}, 'origin': '218.186.161.221', 'url': 'https://httpbin.org/get'} expected_status_code = '200' def check_status(self, resp, expected_status_code): self.log.info(" -------- Checking the Expected Status {} ".format(expected_status_code)) # This return caller function's name, not this function post. caller_func_name = inspect.stack()[1][3] > if int(resp.status_code) != int(expected_status_code): E AttributeError: 'dict' object has no attribute 'status_code' base/APIHelpers/request_methods.py:94: AttributeError